@@ -1,5 +1,5 @@
 use serde::de::DeserializeOwned;
-use serde::{Serialize};
+use serde::Serialize;
 
 use crate::{AggregateError, DomainEvent};
 
@@ -107,4 +107,4 @@ pub trait Aggregate: Default + Serialize + DeserializeOwned + Sync + Send {
     /// }
     /// ```
     fn apply(&mut self, event: Self::Event);
-}
\ No newline at end of file
+}
